@@ -243,6 +243,9 @@ def dwm_set_window_attribute(window: tk.Tk, attribute, value):
 
 
 def window_move(widget: tk.Widget, window: tk.Tk):
+    """
+    用于拖动窗口，widget为使窗口移动的组件，window为被移动的窗口
+    """
     def move(evt):
         ReleaseCapture()
         SendMessage(GetParent(window.winfo_id()), WM_SYSCOMMAND,
@@ -252,14 +255,23 @@ def window_move(widget: tk.Widget, window: tk.Tk):
 
 
 def window_dark(window: tk.Tk):
+    """
+    设置黑暗主题
+    """
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, True)
 
 
 def window_light(window: tk.Tk):
+    """
+    设置明亮主题
+    """
     dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, False)
 
 
 def window_screenshot(window: tk.Tk, image_name: str = "Image.png"):
+    """
+    截取窗口图片
+    """
     from tkcap import CAP
     cap = CAP(window)
     window.after(800, cap.capture(image_name))
@@ -267,16 +279,17 @@ def window_screenshot(window: tk.Tk, image_name: str = "Image.png"):
 
 
 def window_acrylic(window: tk.Tk, dark=False, acrylic: bool = False, hexColor: bool = False):
+    """
+    设置窗口背景材质，改为亚克力材质。
+    """
     from BlurWindow.blurWindow import GlobalBlur
     GlobalBlur(GetParent(window.winfo_id()), hexColor=hexColor, Acrylic=acrylic, Dark=dark, QWidget=window)
 
 
-def window_acrylic2(window: tk.Tk, shadow: bool = True):
-    effent = WindowEffect()
-    effent.setAcrylicEffect(hWnd=GetParent(window.winfo_id()), isEnableShadow=shadow)
-
-
 def window_long(window: tk.Tk, long):
+    """
+    用于内部工作的组件，设置窗口，window为设置的组件，long为设置的参数
+    """
     def long():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~long)
@@ -285,21 +298,25 @@ def window_long(window: tk.Tk, long):
 
 
 def window_ex_long(window: tk.Tk, long):
+    """
+    用于内部工作的组件，设置扩展窗口，window为设置的组件，long为设置的参数
+    """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_EXSTYLE, GetWindowLong(hwnd, GWL_EXSTYLE) & ~long)
 
 
 def window_tiled(window: tk.Tk):
+    """
+    设置窗口标题，window为要被设置的窗口
+    """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_TILED)
 
 
-def window_alpha(window: tk.Tk, alpha: int):
-    hwnd = GetParent(window.winfo_id())
-    res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_SIZEBOX)
-
-
 def window_mica_light(window: tk.Tk):
+    """
+    设置窗口背景材质为云母，并将主题设为明亮，window为要被设置的窗口
+    """
     try:
         import win32mica as mc
         mc.debugging = False
@@ -309,6 +326,9 @@ def window_mica_light(window: tk.Tk):
 
 
 def window_mica_dark(window: tk.Tk):
+    """
+    设置窗口背景材质为云母，并将主题设为暗黑，window为要被设置的窗口
+    """
     try:
         import win32mica as mc
         mc.debugging = False
@@ -318,27 +338,42 @@ def window_mica_dark(window: tk.Tk):
 
 
 def window_pos_bottom_right(window: tk.Tk, padx: int = 15, pady: int = 15):
+    """
+    将窗口放在右下位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    """
     window.after(1, lambda: window.geometry(
         f"+{window.winfo_screenwidth() - window.winfo_width() - padx - 10}+"
         f"{window.winfo_screenheight() - taskbar_height - window.winfo_height() - pady - 35}"))
 
 
 def window_pos_bottom_left(window: tk.Tk, padx: int = 15, pady: int = 15):
+    """
+    将窗口放在左下位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    """
     window.after(1, lambda: window.geometry(
         f"+{padx}+{window.winfo_screenheight() - taskbar_height - window.winfo_height() - pady - 35}"))
 
 
 def window_pos_top_right(window: tk.Tk, padx: int = 15, pady: int = 15):
+    """
+    将窗口放在右上位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    """
     window.after(1, lambda: window.geometry(
         f"+{window.winfo_screenwidth() - window.winfo_width() - padx - 10}+{pady}"))
 
 
 def window_pos_top_left(window: tk.Tk, padx: int = 15, pady: int = 15):
+    """
+    将窗口放在左上位置，window为要被设置的窗口，padx表示X间距，pady表示Y间距
+    """
     window.after(1, lambda: window.geometry(
         f"+{padx}+{pady}"))
 
 
 def window_sizebox(window: tk.Tk):
+    """
+    设置窗口是否有调整大小的边框，window为要被设置的窗口
+    """
     def sizebox():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_SIZEBOX)
@@ -347,6 +382,9 @@ def window_sizebox(window: tk.Tk):
 
 
 def window_maxbox(window: tk.Tk):
+    """
+    设置窗口是否有最大化按钮，window为要被设置的窗口
+    """
     def max():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_MAXIMIZEBOX)
@@ -355,6 +393,9 @@ def window_maxbox(window: tk.Tk):
 
 
 def window_minbox(window: tk.Tk):
+    """
+    设置窗口是否有最小化按钮，window为要被设置的窗口
+    """
     def min():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_MINIMIZEBOX)
@@ -363,6 +404,9 @@ def window_minbox(window: tk.Tk):
 
 
 def window_grayed_closebox(window: tk.Tk):
+    """
+    禁用关闭按钮，window为要被设置的窗口
+    """
     def close():
         hwnd = GetParent(window.winfo_id())
         res = EnableMenuItem(GetSystemMenu(hwnd, False), SC_CLOSE, MF_BYCOMMAND | MF_GRAYED)
@@ -371,6 +415,9 @@ def window_grayed_closebox(window: tk.Tk):
 
 
 def window_enabled_closebox(window: tk.Tk):
+    """
+    启用关闭按钮，window为要被设置的窗口
+    """
     def close():
         hwnd = GetParent(window.winfo_id())
         res = EnableMenuItem(GetSystemMenu(hwnd, False), SC_CLOSE, MF_BYCOMMAND | MF_ENABLED)
@@ -379,6 +426,9 @@ def window_enabled_closebox(window: tk.Tk):
 
 
 def window_popup(window: tk.Tk):
+    """
+    使窗口变成弹出状态，window为要被设置的窗口
+    """
     def popup():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_POPUPWINDOW)
@@ -387,6 +437,9 @@ def window_popup(window: tk.Tk):
 
 
 def window_custom_taskbar(window: tk.Tk):
+    """
+    自定义窗口，出现在任务栏中，window为要被设置的窗口
+    """
     def over():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_OVERLAPPEDWINDOW)
@@ -397,6 +450,9 @@ def window_custom_taskbar(window: tk.Tk):
 
 
 def window_custom_border_taskbar(window: tk.Tk):
+    """
+    自定义窗口，保留边框，出现在任务栏中，window为要被设置的窗口
+    """
     def custom():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_BORDER)
@@ -406,6 +462,9 @@ def window_custom_border_taskbar(window: tk.Tk):
 
 
 def window_add_taskbar(window: tk.Tk):
+    """
+    将窗口放入任务栏
+    """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_EXSTYLE, GetWindowLong(hwnd, GWL_EXSTYLE) & ~WS_EX_TOOLWINDOW | WS_EX_APPWINDOW)
     # re-assert the new window style
@@ -414,6 +473,9 @@ def window_add_taskbar(window: tk.Tk):
 
 
 def window_border(window: tk.Tk):
+    """
+    使窗口保留边框，去除标题栏，window为要被设置的窗口
+    """
     def border():
         hWnd = GetParent(window.winfo_id())
         SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
@@ -424,6 +486,9 @@ def window_border(window: tk.Tk):
 
 
 def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
+    """
+    将窗口嵌入到容器里，window设置为被嵌入的容器，toplevel设置为嵌入的窗口，iswindow确认容器是否使窗口
+    """
     def embed():
         SetParent(GetParent(toplevel.winfo_id()), window.winfo_id())
         toplevel.deiconify()
@@ -436,18 +501,27 @@ def window_embed(window: tk.Tk, toplevel: tk.Toplevel, iswindow: bool = True):
 
 
 def window_centre(window: tk.Tk):
+    """
+    将窗口居中，window为要被设置的窗口
+    """
     x = window.winfo_screenwidth() / 2 - window.winfo_width() / 2
     y = window.winfo_screenheight() / 2 - window.winfo_height() / 2
     window.geometry(f"{window.winfo_width()}x{window.winfo_height()}+{round(x)}+{round(y)}")
 
 
 def window_custom(window: tk.Tk):
+    """
+    去除窗口标题栏，window为要被设置的窗口
+    """
     hwnd = GetParent(window.winfo_id())
     res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~WS_CAPTION)
     window.update()
 
 
 def resize_widget(widget: tk.Widget, size: int = 10):
+    """
+    使窗口可以被调整
+    """
     try:
         widget.after(1, lambda: DevResize(widget, size=size))
     except tk.TclError:
@@ -462,11 +536,17 @@ class DevAccumulatorButton(tk.Button):
 
 class DevAppBar(tk.Frame):
     def __init__(self, master: tk.Widget = None, title: str = "", background="#ffffff", foreground="#000000"):
+        """
+        应用程序栏，
+        """
         super(DevAppBar, self).__init__(master=master, relief=tk.FLAT, background=background)
         self.title = tk.Label(self, text=title, justify=tk.LEFT, background=background, foreground=foreground)
         self.title.pack(fill=tk.Y, side=tk.LEFT, padx=10, pady=5)
 
     def show(self):
+        """
+        显示组件在窗口的最上方
+        """
         self.pack(fill=tk.X, ipadx=10, ipady=10)
 
 
@@ -503,8 +583,8 @@ class DevDrag(object):
     def __init__(self, widget: tk.Widget, dragwidget: tk.Widget, iswindow: bool = False, x: bool = True, y: bool = True,
                  click_func=None, noclick_func=None, move_func=None):
         """
-        这个组件能够拖动组件移动，实现更高级的功能 \n widget设为拖动命令的组件，你拖动这个组件，拖动的组件会移动 \n dragwidget设为被拖动的组件 \n
-        iswindow是声明你要拖动的组件是窗口还是组件，是窗口填True，是组件填False
+        这个组件能够拖动组件移动，实现更高级的功能。widget设为拖动命令的组件，你拖动这个组件，拖动的组件会移动。dragwidget设为被拖动的组件。
+        iswindow是声明你要拖动的组件是窗口还是组件，是窗口填True，是组件填False。
 
         :param widget:
         :param dragwidget:
@@ -532,6 +612,9 @@ class DevDrag(object):
         self.y = y
 
     def move(self, event=None):
+        """
+        内置函数，处理被拖动时移动
+        """
         if not self.moved.get():
             return
 
@@ -553,11 +636,17 @@ class DevDrag(object):
         self.widget.update()
 
     def click(self, event=None):
+        """
+        内置函数，处理被点击时记录按下时的位置信息
+        """
         self.movex.set(event.x)
         self.movey.set(event.y)
         self.moved.set(True)
 
     def noclick(self, event=None):
+        """
+        内置函数，处理放开后设置是否按下为否
+        """
         self.moved.set(False)
 
 
@@ -606,6 +695,9 @@ class DevFoldFrame(tk.Frame):
 
 class DevHeaderBar(tk.Frame):
     def __init__(self, master: tk.Tk, border: bool = True, background="#ffffff", double_max: bool = True):
+        """
+        标题栏组件，能够自定义窗口标题栏。master为被设置窗口，border设置是否保留边框，background设置标题栏背景，double_max设置是否可以通过双击按钮最大化。
+        """
         super(DevHeaderBar, self).__init__(master=master, background=background, height=35)
         self.master = master
         self.master.configure(background="#fdfdfd")
@@ -622,6 +714,10 @@ class DevHeaderBar(tk.Frame):
     def add_close_button(self, text: str = "🗙", font=("微软雅黑", 9),
                          background="#ffffff", foreground="#000000",
                          activebackground="#c42b1c", activeforeground="#ffffff"):
+        """
+        为标题栏添加关闭按钮，text为关闭按钮的文本，font为关闭按钮的字体，background为关闭按钮的背景颜色，foreground为关闭按钮的前景颜色，
+        activebackground为关闭按钮触发时的背景颜色，activeforeground为关闭按钮触发时的前景颜色
+        """
         self.close_button = tk.Button(self, text=text, border=0, font=font,
                                       background=background, foreground=foreground,
                                       activebackground=activebackground, activeforeground=activeforeground,
@@ -631,6 +727,10 @@ class DevHeaderBar(tk.Frame):
     def add_maximize_button(self, text: str = "🗖", font=("微软雅黑", 9),
                             background="#ffffff", foreground="#000000",
                             activebackground="#e9e9e9", activeforeground="#b5b5b5"):
+        """
+        为标题栏添加最大化按钮，text为最大化按钮的文本，font为最大化按钮的字体，background为最大化按钮的背景颜色，
+        foreground为最大化按钮的前景颜色，activebackground为最大化按钮触发时的背景颜色，activeforeground为最大化按钮触发时的前景颜色
+        """
         self.maxmize_button = tk.Button(self, text=text, border=0, font=font,
                                         background=background, foreground=foreground,
                                         activebackground=activebackground, activeforeground=activeforeground,
@@ -640,6 +740,10 @@ class DevHeaderBar(tk.Frame):
     def add_minimize_button(self, text: str = "🗕", font=("微软雅黑", 9),
                             background="#ffffff", foreground="#000000",
                             activebackground="#e9e9e9", activeforeground="#b5b5b5"):
+        """
+        为标题栏添加最小化按钮，text为最小化按钮的文本，font为最小化按钮的字体，background为最小化按钮的背景颜色，
+        foreground为最小化按钮的前景颜色，activebackground为最小化按钮触发时的背景颜色，activeforeground为最小化按钮触发时的前景颜色
+        """
         self.minimize_button = tk.Button(self, text=text, border=0, font=font,
                                          background=background, foreground=foreground,
                                          activebackground=activebackground, activeforeground=activeforeground,
@@ -647,6 +751,9 @@ class DevHeaderBar(tk.Frame):
         self.minimize_button.pack(side=tk.RIGHT, ipady=2, ipadx=12, fill=tk.Y)
 
     def maximize_event(self):
+        """
+        内置函数，使窗口最大化
+        """
         if self.ismaximize:
             self.master.state("normal")
             self.maxmize_button.configure(text="🗖")
@@ -657,9 +764,15 @@ class DevHeaderBar(tk.Frame):
             self.ismaximize = True
 
     def minimize(self):
+        """
+        内置函数，使窗口最小化
+        """
         self.master.state('icon')
 
     def maximize(self):
+        """
+        内置函数，使窗口最大化
+        """
         if self.ismaximize:
             self.master.state("normal")
             self.ismaximize = False
@@ -693,15 +806,27 @@ class DevMenuBar(tk.Frame):
 
 class DevObject(object):
     def __init__(self):
+        """
+        可以用于存储组件
+        """
         self.obj = {}
 
     def add_widget(self, widget: tk.Widget, id: str):
+        """
+        添加组件，widget为被存储的组件，id为存储组件的ID
+        """
         self.obj[id] = widget
 
     def set_widget(self, id: str, widget: tk.Widget):
+        """
+        设置组件，id为存储组件的ID，widget为被存储的组件
+        """
         self.obj[id] = widget
 
     def get_widget(self, id: str) -> tk.Widget:
+        """
+        获取组件，id为存储组件的ID
+        """
         return self.obj[id]
 
 
@@ -929,23 +1054,29 @@ class DevTabber(tk.Frame):
 
 class DevWindow(tk.Tk):
     def __init__(self, title: str = ""):
+        """
+        快捷使用窗口，内置多种功能，快速使用
+        """
         super(DevWindow, self).__init__()
         from sys import getwindowsversion
         self.title(title)
         self.geometry("630x300")
         self.iconbitmap(Icon_Empty)
         self.configure(background="#ffffff")
-        if getwindowsversion().build >= 22621:
-            # 因为22621版本号改了标题栏，所以就改成标题栏的颜色
-            self.configure(background="#eff4f9")
 
     def wm_screenshot(self, image="Image.png"):
+        """
+        截取窗口
+        """
         window_screenshot(self, image)
 
     screenshot = wm_screenshot
 
     def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto,
                    mica: bool = False, acrylic: bool = False, hexColor: bool = False):
+        """
+        设置窗口材质为亚克力，mode为主题默认是自动
+        """
         if mica:
             self.mica(mode)
 
@@ -967,6 +1098,9 @@ class DevWindow(tk.Tk):
     acrylic = wm_acrylic
 
     def wm_mica(self, mode: Literal["auto", "light", "dark"] = Auto, all: bool = False):
+        """
+        设置窗口材质为云母，mode为主题默认是自动，all选择是否隐藏整个窗口。
+        """
         import platform
         if platform.system() == "Windows":
             if all:
@@ -991,28 +1125,43 @@ class DevWindow(tk.Tk):
     mica = wm_mica
 
     def wm_remove_titlebar(self):
+        """
+        移除标题栏与边框，保留着任务栏
+        """
         self.after(0, lambda: window_custom_border_taskbar(self))
 
     remove_titlebar = wm_remove_titlebar
 
     def wm_remove_titlebar_none_border(self):
+        """
+        移除标题栏，无边框
+        """
         window_custom_taskbar(self)
 
     remove_titlebar_none_border = wm_remove_titlebar_none_border
 
     def wm_run(self):
+        """
+        运行窗口，没什么作用
+        """
         self.mainloop()
 
     run = wm_run
 
     def wm_statusbar(self, statusBar: tk.Widget = None):
+        """
+        设置状态栏，statusBar为被设置的状态栏
+        """
         self._statusBar = statusBar
         self._statusBar.pack(fill=tk.X, side=tk.BOTTOM)
         return self._statusBar
 
     statusbar = wm_statusbar
 
-    def wm_titlebar(self, titleBar: DevHeaderBar = None, overtitlebar: bool = True, border: bool = True):
+    def wm_titlebar(self, titleBar: DevHeaderBar = None):
+        """
+        设置标题栏，titleBar为被设置的标题栏
+        """
         self.minsize(100, 30)
         self._titlebar = titleBar
         self._titlebar.pack(fill=tk.X, side=tk.TOP)
@@ -1026,14 +1175,23 @@ class DevWindow(tk.Tk):
     menubar = wm_menubar
 
     def wm_centre(self):
+        """
+        居中窗口
+        """
         self.after(1, lambda evt=None: window_centre(self))
 
     centre = wm_centre
 
     def min_window(self):
+        """
+        最小化窗口
+        """
         self.state("iconic")
 
     def dpi(self):
+        """
+        设置dpi高清晰度
+        """
         self.tk.call('tk', 'scaling', ScaleFactor / 75)
 
 
@@ -1083,6 +1241,9 @@ class DevTooltip(DevToplevel):
 
     @property
     def after_ms(self):
+        """
+        等待的毫秒
+        """
         return self._afterms
 
     @after_ms.setter
@@ -1091,6 +1252,9 @@ class DevTooltip(DevToplevel):
 
     @property
     def message(self):
+        """
+        工具提示的消息
+        """
         return self.message
 
     @message.setter
@@ -1098,11 +1262,17 @@ class DevTooltip(DevToplevel):
         self._message.configure(text=text)
 
     def hide(self):
+        """
+        内置函数，用于隐藏窗口
+        """
         self.ison = False
         self.window.deiconify()
         self.withdraw()
 
     def show(self):
+        """
+        内置函数，用于显示窗口
+        """
         self.ison = True
 
         def on():
